@@ -243,19 +243,24 @@ class ParsedUrl:
             self.password = pu.password
         except:
             raise InvalidBackendURL("Syntax error (password) in: %s" % url_string)
+        if self.password:
+            self.password = urllib.unquote(self.password)
+        else:
+            self.password = None
 
         try:
             self.hostname = pu.hostname
         except:
             raise InvalidBackendURL("Syntax error (hostname) in: %s" % url_string)
 
-        if self.scheme not in ['rsync']:
-            try:
-                self.port = pu.port
-            except:
-                raise InvalidBackendURL("Syntax error (port) in: %s" % url_string)
-        else:
-            self.port = None
+        # init to None, overwrite with actual value on success
+        self.port = None
+        try:
+            self.port = pu.port
+        except:
+            # old style rsync://host::[/]dest, are still valid, though they contain no port
+            if not ( self.scheme in ['rsync'] and re.search('::[^:]*$', self.url_string)):
+                raise InvalidBackendURL("Syntax error (port) in: %s A%s B%s C%s" % (url_string, (self.scheme in ['rsync']), re.search('::[^:]+$', self.netloc), self.netloc ) )
 
         # This happens for implicit local paths.
         if not pu.scheme:
@@ -328,6 +333,9 @@ class Backend:
         """
         raise NotImplementedError()
 
+    """ use getpass by default, inherited backends may overwrite this behaviour """
+    use_getpass = True
+
     def get_password(self):
         """
         Return a password for authentication purposes. The password
@@ -341,8 +349,12 @@ class Backend:
         try:
             password = os.environ['FTP_PASSWORD']
         except KeyError:
-            password = getpass.getpass("Password for '%s': " % self.parsed_url.hostname)
-            os.environ['FTP_PASSWORD'] = password
+            if self.use_getpass:
+                password = getpass.getpass("Password for '%s@%s': " %
+                                           (self.parsed_url.username,self.parsed_url.hostname) )
+                os.environ['FTP_PASSWORD'] = password
+            else:
+                password = None
         return password
 
     def munge_password(self, commandline):
