@@ -21,10 +21,10 @@
 
 """Store global configuration information"""
 
-import socket, sys, os
+import socket, os
 
 # The current version of duplicity
-version = "0.6.06"
+version = "0.6.10"
 
 # The name of the current host, or None if it cannot be set
 hostname = socket.getfqdn()
@@ -66,6 +66,9 @@ select = None
 # files.  Replaces encryption_keys, sign_key, and passphrase settings.
 gpg_profile = None
 
+# Options to pass to gpg
+gpg_options = ''
+
 # If true, filelists and directory statistics will be split on
 # nulls instead of newlines.
 null_separator = None
@@ -87,10 +90,10 @@ allow_source_mismatch = None
 incremental = None
 
 # If set, print the statistics after every backup session
-print_statistics = 1
+print_statistics = True
 
 # If set, use short (< 30 char) filenames for all the remote files.
-short_filenames = 0
+short_filenames = False
 
 # If set, forces a full backup if the last full backup is older than
 # the time specified
@@ -104,10 +107,16 @@ force = None
 # be deleted.
 remove_time = None
 
-# If set, signifies the number of backups chains to keep when perfroming
-# a --remove-all-but-n-full.
+# If set, signifies the number of backups chains to keep when performing
+# a remove-all-but-n-full.
 keep_chains = None
 
+# If set, signifies that remove-all-but-n-full in progress
+remove_all_but_n_full_mode = None
+
+# If set, signifies that remove-all-inc-of-but-n-full in progress (variant of remove-all-but-n-full)
+remove_all_inc_of_but_n_full_mode = None
+
 # Don't actually do anything, but still report what would be done
 dry_run = False
 
@@ -142,6 +151,9 @@ s3_use_new_style = False
 # support european for now).
 s3_european_buckets = False
 
+# Whether to use S3 Reduced Redudancy Storage
+s3_use_rrs = False
+
 # Whether to use the full email address as the user name when
 # logging into an imap server. If false just the user name
 # part of the email address is used.
@@ -167,6 +179,9 @@ ssh_askpass = False
 # user added ssh options
 ssh_options = ""
 
+# whether to use scp for put/get, sftp is default
+use_scp = False
+
 # will be a Restart object if restarting
 restart = None
 
@@ -181,3 +196,6 @@ ignore_errors = False
 
 # If we should be particularly aggressive when cleaning up
 extra_clean = False
+
+# Renames (--rename)
+rename = {}
