@@ -19,6 +19,16 @@
 # along with duplicity; if not, write to the Free Software Foundation,
 # Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
+import os #@UnusedImport
+import re #@UnusedImport
+import stat #@UnusedImport
+
+from duplicity.path import * #@UnusedWildImport
+from duplicity import log #@Reimport
+from duplicity import globals #@Reimport
+from duplicity import diffdir
+from duplicity import util #@Reimport
+
 """Iterate exactly the requested files in a directory
 
 Parses includes and excludes to yield correct files.  More
@@ -26,16 +36,6 @@ documentation on what this code does can be found on the man page.
 
 """
 
-import os
-import re
-import stat
-
-from duplicity.path import *
-from duplicity import log
-from duplicity import globals
-from duplicity import diffdir
-from duplicity import util
-
 class SelectError(Exception):
     """Some error dealing with the Select class"""
     pass
@@ -137,7 +137,7 @@ class Select:
 
             """
             # todo: get around circular dependency issue by importing here
-            from duplicity import robust
+            from duplicity import robust #@Reimport
             for filename in robust.listpath(path):
                 new_path = robust.check_common_error(
                     error_handler, Path.append, (path, filename))
@@ -271,7 +271,7 @@ cannot match any files in the base directory
 Useful file specifications begin with the base directory or some
 pattern (such as '**') which matches the base directory.""") %
             (exc, self.prefix), log.ErrorCode.file_prefix_error)
-        elif isinstance(e, GlobbingError):
+        elif isinstance(exc, GlobbingError):
             log.FatalError(_("Fatal Error while processing expression\n"
                              "%s") % exc, log.ErrorCode.globbing_error)
         else:
